@@ -8,6 +8,9 @@ import time
 from collections import Counter
 import itertools
 from scipy.optimize import linprog
+import sys
+
+sys.setrecursionlimit(int(1e4))
 
 def seed_patterns(w, q, B, n, max_combinations=3, goal=3, verbiose=True):
     '''
@@ -51,11 +54,20 @@ def seed_patterns(w, q, B, n, max_combinations=3, goal=3, verbiose=True):
         print("{} possible max {} combinations".format(len(combos),max_combinations))
     patterns = []
     for combo in combos:
+        # due to the naive soln, combos of len 1 should be skipped.
+
         # knapsack/store_patterns will only find one solution (0?) if
         # the width is over half the length of the bin
         if len(combo) == 1:
-            if B / combo[0] < 2:
-                sub_goal = 1
+            sub_goal = 1
+
+        # arbitrary conditional
+        elif sum(combo) > (B - min(combo)):
+            sub_goal = 1
+            # if B / combo[0] < 2:
+            #     sub_goal = 1
+            # else:
+            #     sub_goal = goal
         else:
             sub_goal = goal
         # only provide knapsack with relevant variables
@@ -113,10 +125,10 @@ def knapsack(wt, val, W, n, t):
 
 def store_patterns(t, s, B, goal=5):
     patterns = []
-    bit = 0
-    while len(patterns) < goal:
+    bit = 1
+    while (len(patterns) < goal):
         found = 0
-        for pair in np.argwhere(t == t.max()-bit):
+        for pair in np.argwhere(t == t.flatten()[t.flatten().argsort()[-bit]]):
             N, W = pair
             sack = reconstruct(N, W, t, s)
             pattern = Counter(np.array(s)[list(sack)])
@@ -129,7 +141,7 @@ def store_patterns(t, s, B, goal=5):
             found += 1
             if found > 1:
                 break
-        bit += 2
+        bit += 1
     return patterns
 
 def reconstruct(i, w, kp_soln, weight_of_item):
@@ -178,6 +190,11 @@ def make_best_pattern(q, w, n, usable_width=4160, verbiose=True):
     layout: list
         cuts for jumbo for each width (no width is excluded)
     """
+
+    # if not all slits can fit in a single bin, do not return a single optimum layout
+    if np.sum([n,w]) > usable_width:
+        return None
+
     layout = [max(1, math.floor(i/sum(q)*usable_width/j)) for i,j in zip(q,w)]
 
 
@@ -187,9 +204,8 @@ def make_best_pattern(q, w, n, usable_width=4160, verbiose=True):
                                                         < 0) else -1 for i,j in zip(q,w) ]
     order = np.argsort(remainder)
     # sometimes the floor still puts us over
-    for i in range(3):
-        if usable_width - sum([i*j for i,j in zip(layout,w)]) < 0:
-            layout[np.argmax(layout)] -= 1
+    while usable_width - sum([i*j for i,j in zip(layout,w)]) < 0:
+        layout[np.argmax(layout)] -= 1
 
     while (usable_width - sum([i*j for i,j in zip(layout,w)])) > min(w):
         for i in order[::-1]:
@@ -332,7 +348,7 @@ def find_optimum(patterns, layout, w, q, B, n, L, max_combinations=3,
         inv_loss = 1
     if 1 < max_patterns < 4:
         # find best of X combination
-        if len(w) <= max_combinations:
+        if (len(w) <= max_combinations) and (layout != None):
             pattern_combos = list(itertools.combinations(patterns,r=max_patterns-1))
         else:
             pattern_combos = list(itertools.combinations(patterns,r=max_patterns))
@@ -351,7 +367,7 @@ def find_optimum(patterns, layout, w, q, B, n, L, max_combinations=3,
                 lhs_ineq.append(inset)
         #     naive = init_layouts(B, w)
         #     lhs_ineq = lhs_ineq + naive
-            if len(w) <= max_combinations:
+            if (len(w) <= max_combinations) and (layout != None):
                 lhs_ineq.append([-i for i in layout])
             lhs_ineq = np.array(lhs_ineq).T.tolist()
             rhs_ineq = [-i for i in q]
@@ -419,7 +435,7 @@ def find_optimum(patterns, layout, w, q, B, n, L, max_combinations=3,
     # naive = init_layouts(B, w)
     # lhs_ineq = lhs_ineq + naive
 
-    if len(w) <= max_combinations:
+    if (len(w) <= max_combinations) and (layout != None):
         lhs_ineq.append([-i for i in layout])
     lhs_ineq = np.array(lhs_ineq).T.tolist()
     rhs_ineq = [-i for i in q]
